import * as path from 'path';
import { LanguageClient, LanguageClientOptions, ServerOptions, TransportKind } from 'vscode-languageclient/node';
import * as vscode from 'vscode';

export function activate(context: vscode.ExtensionContext) {
  const serverModule = path.join(context.extensionPath, 'server', 'server.js');
  const serverOptions: ServerOptions = {
    run: { module: serverModule, transport: TransportKind.ipc },
    debug: { module: serverModule, transport: TransportKind.ipc, options: { execArgv: ['--nolazy', '--inspect=6009'] } }
  };

  const clientOptions: LanguageClientOptions = {
    documentSelector: [{ scheme: 'file', language: 'rust' }],
    synchronize: {
      fileEvents: vscode.workspace.createFileSystemWatcher('**/.clientrc')
    }
  };

  const client = new LanguageClient('rustLanguageServer', 'Rust Language Server', serverOptions, clientOptions);

  // Start the client. This returns a Promise, so we handle it properly.
  const startPromise = client.start();

  // Push the client itself as a disposable.
  context.subscriptions.push(client);

  // Optionally, handle the promise if needed
  startPromise.catch(err => {
    console.error('Failed to start language client:', err);
  });
}
